@@ -13,4 +13,6 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+# for compatibility
 from blockdiag.drawer import DiagramDraw
+DiagramDraw
