@@ -52,8 +52,8 @@ class DiagramDraw(object):
                       nodoctype=kwargs.get('nodoctype'),
                       scale_ratio=self.scale_ratio,
                       transparency=kwargs.get('transparency'))
-        drawer = imagedraw.create(self.format, self.filename,
-                                  self.pagesize(), **kwargs)
+        drawer = imagedraw.create(self.format, self.filename, self.pagesize(),
+                                  shadow_style=diagram.shadow_style, **kwargs)
         if drawer is None:
             msg = 'failed to load %s image driver' % self.format
             raise RuntimeError(msg)
@@ -75,7 +75,7 @@ class DiagramDraw(object):
     @property
     def edges(self):
         edges = self.diagram.traverse_edges(preorder=True)
-        for edge in (e for e in edges  if e.style != 'none'):
+        for edge in (e for e in edges if e.style != 'none'):
             yield edge
 
     def pagesize(self, scaled=False):
@@ -118,7 +118,7 @@ class DiagramDraw(object):
 
         # Drop node shadows.
         for node in self.nodes:
-            if node.color != 'none':
+            if node.color != 'none' and self.diagram.shadow_style != 'none':
                 r = noderenderer.get(node.shape)
 
                 shape = r(node, self.metrics)
@@ -128,7 +128,8 @@ class DiagramDraw(object):
                     drawer = self.drawer
 
                 shape.render(drawer, self.format,
-                             fill=self.shadow, shadow=True)
+                             fill=self.shadow, shadow=True,
+                             style=self.diagram.shadow_style)
 
     def _draw_elements(self, **kwargs):
         for node in self.nodes:
@@ -137,6 +138,9 @@ class DiagramDraw(object):
         for edge in self.edges:
             self.edge(edge)
 
+        for edge in self.edges:
+            self.edge_label(edge)
+
         for group in self.groups:
             if group.shape == 'line':
                 box = self.metrics.group(group).marginbox
@@ -181,7 +185,10 @@ class DiagramDraw(object):
             else:
                 self.drawer.polygon(head, outline=edge.color, fill=edge.color)
 
+    def edge_label(self, edge):
         if edge.label:
+            metrics = self.metrics.edge(edge)
+
             font = self.metrics.font_for(edge)
             self.drawer.textarea(metrics.labelbox, edge.label, font=font,
                                  fill=edge.textcolor, outline=self.fill)
