@@ -18,7 +18,7 @@ from elements import DiagramNode
 import noderenderer
 from utils import Box, Size, XY
 from utils.fontmap import FontInfo, FontMap
-from utils.collections import defaultdict, namedtuple
+from utils.collections import defaultdict
 
 cellsize = 8
 
@@ -42,7 +42,7 @@ class EdgeLines(object):
         else:
             elem = XY(x, y)
 
-        if self.stroking == False:
+        if self.stroking is False:
             self.stroking = True
             polyline = []
             if self.xy:
@@ -73,19 +73,25 @@ class AutoScaler(object):
 
     def __getattr__(self, name):
         ratio = self.scale_ratio
-        attr = getattr(self.subject, name)
+        return self.scale(getattr(self.subject, name), ratio)
 
-        if not callable(attr):
-            return self.scale(attr, ratio)
+    def __getitem__(self, name):
+        ratio = self.scale_ratio
+        return self.scale(self.subject[name], ratio)
+
+    @classmethod
+    def scale(cls, value, ratio):
+        if not callable(value):
+            return cls._scale(value, ratio)
         else:
             def _(*args, **kwargs):
-                ret = attr(*args, **kwargs)
-                return self.scale(ret, ratio)
+                ret = value(*args, **kwargs)
+                return cls._scale(ret, ratio)
 
             return _
 
     @classmethod
-    def scale(cls, value, ratio):
+    def _scale(cls, value, ratio):
         if ratio == 1:
             return value
 
@@ -194,10 +200,13 @@ class DiagramMetrics(object):
         try:
             if font is None:
                 from utils.TextFolder import TextFolder
+                TextFolder = TextFolder
             elif self.format == 'PDF':
-                from utils.PDFTextFolder import PDFTextFolder as TextFolder
+                from utils.PDFTextFolder import PDFTextFolder
+                TextFolder = PDFTextFolder
             else:
-                from utils.PILTextFolder import PILTextFolder as TextFolder
+                from utils.PILTextFolder import PILTextFolder
+                TextFolder = PILTextFolder
         except ImportError:
             from utils.TextFolder import TextFolder
 
@@ -944,9 +953,7 @@ class FlowchartLandscapeEdgeMetrics(LandscapeEdgeMetrics):
         dir = self.edge.direction
         if dir == 'right':
             span = XY(self.metrics.span_width, self.metrics.span_height)
-            node1 = self.metrics.node(self.edge.node1)
             cell1 = self.metrics.cell(self.edge.node1, use_padding=False)
-            node2 = self.metrics.node(self.edge.node2)
             cell2 = self.metrics.cell(self.edge.node2, use_padding=False)
 
             if self.edge.skipped:
@@ -1018,9 +1025,7 @@ class FlowchartPortraitEdgeMetrics(PortraitEdgeMetrics):
     def labelbox(self):
         dir = self.edge.direction
         span = XY(self.metrics.span_width, self.metrics.span_height)
-        node1 = self.metrics.node(self.edge.node1)
         cell1 = self.metrics.cell(self.edge.node1, use_padding=False)
-        node2 = self.metrics.node(self.edge.node2)
         cell2 = self.metrics.cell(self.edge.node2, use_padding=False)
 
         if dir == 'down':
