@@ -23,6 +23,7 @@ from blockdiag.utils.fontmap import parse_fontpath, FontMap
 
 class Application(object):
     module = None
+    option = None
 
     def run(self):
         try:
@@ -39,7 +40,7 @@ class Application(object):
             sys.stderr.write(msg)
             return -1
         except Exception, e:
-            if self.options.debug:
+            if self.option and self.options.debug:
                 import traceback
                 traceback.print_exc()
             else:
@@ -73,7 +74,11 @@ class Application(object):
                              nodoctype=self.options.nodoctype,
                              transparency=self.options.transparency)
         drawer.draw()
-        drawer.save()
+
+        if self.options.size:
+            drawer.save(size=self.options.size)
+        else:
+            drawer.save()
 
         return 0
 
@@ -108,8 +113,10 @@ class Options(object):
                      help='use FONTMAP file to draw diagram', metavar='FONT')
         p.add_option('--no-transparency', dest='transparency',
                      default=True, action='store_false',
-                     help='do not make transparent background of diagram ' +\
+                     help='do not make transparent background of diagram ' +
                           '(PNG only)')
+        p.add_option('--size',
+                     help='Size of diagram (ex. 320x240)')
         p.add_option('-T', dest='type', default='PNG',
                      help='Output diagram as TYPE format')
         p.add_option('--nodoctype', action='store_true',
@@ -137,9 +144,18 @@ class Options(object):
             msg = "unknown format: %s" % self.options.type
             raise RuntimeError(msg)
 
+        if self.options.size:
+            matched = re.match('^(\d+)x(\d+)$', self.options.size)
+            if matched:
+                self.options.size = [int(n) for n in matched.groups()]
+            else:
+                msg = "--size option must be formatted as WIDTHxHEIGHT."
+                raise RuntimeError(msg)
+
         if self.options.type == 'PDF':
             try:
                 import reportlab.pdfgen.canvas
+                reportlab.pdfgen.canvas
             except ImportError:
                 msg = "could not output PDF format; Install reportlab."
                 raise RuntimeError(msg)
@@ -183,27 +199,32 @@ class Options(object):
                 if self.options.fontmap is None:
                     self.options.fontmap = config.get(appname, 'fontmap')
 
+            if config.has_option(appname, 'antialias'):
+                antialias = config.get(appname, 'antialias')
+                if antialias.lower() == 'true':
+                    self.options.antialias = True
+
             if self.options.fontmap is None:
                 self.options.fontmap = configpath
 
 
 def detectfont(options):
-    fonts = [
-        # for Windows
-        'c:/windows/fonts/VL-Gothic-Regular.ttf',
-        'c:/windows/fonts/msgothic.ttf',
-        'c:/windows/fonts/msgoth04.ttc',
-        # for Debian (squeeze)
-        '/usr/share/fonts/truetype/ipafont/ipagp.ttf',
-        '/usr/share/fonts/truetype/vlgothic/VL-PGothic-Regular.ttf',
-        # for Debian (wheezy)
-        '/usr/share/fonts/opentype/ipafont-gothic/ipagp.ttf',
-        '/usr/share/fonts/truetype/vlgothic/VL-PGothic-Regular.ttf',
-        # for MacOS
-        '/Library/Fonts/Hiragino Sans GB W3.otf',  # for MacOS
-        '/System/Library/Fonts/AppleGothic.ttf',  # for MacOS
-        # for FreeBSD
-        '/usr/local/share/font-ipa/ipagp.otf',  # for FreeBSD
+    import glob
+    fontdirs = [
+        '/usr/share/fonts',
+        '/Library/Fonts',
+        '/System/Library/Fonts',
+        'c:/windows/fonts',
+        '/usr/local/share/font-*',
+    ]
+    fontfiles = [
+        'ipagp.ttf',
+        'ipagp.otf',
+        'VL-PGothic-Regular.ttf',
+        'Hiragino Sans GB W3.otf',
+        'AppleGothic.ttf',
+        'msgothic.ttf',
+        'msgoth04.ttf',
     ]
 
     fontpath = None
@@ -217,12 +238,13 @@ def detectfont(options):
             msg = 'fontfile is not found: %s' % options.font
             raise RuntimeError(msg)
 
-    if fontpath is None:
-        for path in fonts:
-            _path, index = parse_fontpath(path)
-            if os.path.isfile(_path):
-                fontpath = path
-                break
+    globber = (glob.glob(d) for d in fontdirs)
+    for fontdir in sum(globber, []):
+        for root, dirs, files in os.walk(fontdir):
+            for font in fontfiles:
+                if font in files:
+                    fontpath = os.path.join(root, font)
+                    break
 
     return fontpath
 
